==> james-project-3.7.6-source-release.zip: james-project/server/container/guice/onami/src/test/java/org/apache/james/onami/lifecycle/StageObject1.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.onami.lifecycle;

import javax.inject.Inject;

public class StageObject1 {
    private final StringBuilder str;

    @Inject
    public StageObject1(StringBuilder str) {
        this.str = str;
    }

    @TestAnnotationA
    public void stageA() {
        str.append("1a");
    }

    @TestAnnotationB
    public void stageB() {
        str.append("1b");
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/onami/src/test/java/org/apache/james/onami/lifecycle/StageObject1.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.onami.lifecycle;

import jakarta.inject.Inject;

public class StageObject1 {
    private final StringBuilder str;

    @Inject
    public StageObject1(StringBuilder str) {
        this.str = str;
    }

    @TestAnnotationA
    public void stageA() {
        str.append("1a");
    }

    @TestAnnotationB
    public void stageB() {
        str.append("1b");
    }
}
